@@ -1,6 +1,5 @@
-import os
+import os, subprocess
 from bionetgen.core.exc import BNGPerlError
-import subprocess
 from distutils import spawn
 
 from bionetgen.core.utils.logging import BNGLogger
@@ -598,7 +597,7 @@ def test_perl(app=None, perl_path=None):
         raise BNGPerlError
     # check if perl is actually working
     command = [perl_path, "-v"]
-    rc, _ = run_command(command, suppress=True)
+    rc, _ = run_command(command)
     if rc != 0:
         raise BNGPerlError
 
@@ -615,14 +614,14 @@ def test_bngexec(bngexec):
         path to BNG2.pl to test
     """
     command = ["perl", bngexec]
-    rc, _ = run_command(command, suppress=True)
+    rc, _ = run_command(command)
     if rc == 0:
         return True
     else:
         return False
 
 
-def run_command(command, suppress=False, timeout=None):
+def run_command(command, suppress=True, timeout=None):
     """
     A convenience function to run a given command. The command should be
     given as a list of values e.g. ['command', 'arg1', 'arg2'] etc.
@@ -632,9 +631,19 @@ def run_command(command, suppress=False, timeout=None):
     be killed.
     """
     if timeout is not None:
-        # I am unsure how to do both timeout and the live polling of stdo
-        rc = subprocess.run(command, timeout=timeout, capture_output=True)
-        return rc.returncode, rc
+        if suppress:
+            # I am unsure how to do both timeout and the live polling of stdo
+            rc = subprocess.run(
+                command,
+                timeout=timeout,
+                stdout=subprocess.DEVNULL,
+                stderr=subprocess.DEVNULL,
+            )
+            return rc.returncode, rc
+        else:
+            # I am unsure how to do both timeout and the live polling of stdo
+            rc = subprocess.run(command, timeout=timeout, capture_output=True)
+            return rc.returncode, rc
     else:
         if suppress:
             process = subprocess.Popen(
